package applicationLogic;

import java.util.ArrayList;
import java.util.Iterator;

/**
 * The Class Manager.
 */
public class Manager {
	
	/** The accomodation list. */
	private ArrayList<Accomodation> accomodationList;
	
	/** The instance. */
	private static Manager instance = null;
	
	/**
	 * Instantiates a new manager.
	 */
	private Manager() {
		accomodationList = new ArrayList<Accomodation>();
	}
	
	/**
	 * Adds the accomodation.
	 *
	 * @param toAdd the to add
	 * @return the int
	 */
	public int addAccomodation(Accomodation toAdd) {
		accomodationList.add(toAdd);
		return toAdd.getId();
	}
	
	/**
	 * Delete accomodation.
	 *
	 * @param id the id
	 * @return true, if successful
	 */
	public boolean deleteAccomodation(int id) 
	{
		Iterator<Accomodation> it = accomodationList.iterator();
		while (it.hasNext())
		{
			Accomodation actual = it.next();
			if (actual.getId() == id) {
				it.remove();
				return true;
			}
		}
		//Object wasn't found in list
		return false;
	}
	
	
	/**
	 * filter accomodations by type. String filterType must be classname from object to filter
	 *
	 * @param filterType the filter type
	 * @return ArrayList from filtered accomodations
	 */
	public ArrayList<Accomodation> filterAccomodations(String filterType) {
		ArrayList<Accomodation> result = new ArrayList<Accomodation>();
		for (Accomodation actual : accomodationList) {
			//Always compare strings by equals not by ==
			if (actual.getClass().getSimpleName().equals(filterType)) {
				result.add(actual);
			}
		}
		return result;
	}
	
	/**
	 * Search accomodations.
	 *
	 * @param zip the zip
	 * @return the array list
	 */
	public ArrayList<Accomodation> searchAccomodations(int zip) {
		ArrayList<Accomodation> result = new ArrayList<Accomodation>();
		for (Accomodation actual : accomodationList) {
			if (actual.getAdr().getZip() == zip) {
				result.add(actual);
			}
		}
		return result;
	}
	
	/**
	 * Singleton design pattern
	 * if no instance is used, create new instance, otherwise return known instance.
	 *
	 * @return single instance of Manager
	 */
	public static Manager getInstance() {
		if (instance == null) {
			instance = new Manager();
		}
		return instance;
	}

	/**
	 * Gets the all persons.
	 *
	 * @return the all persons
	 */
	public ArrayList<Accomodation> getAllPersons() {
		return accomodationList;
	}
}
